summaryrefslogtreecommitdiff
path: root/Source/GetColorTab.S
diff options
context:
space:
mode:
authorChristian A. Weber <chris@gna.ch>1992-05-15 03:21:10 +0000
committerChristian A. Weber <chris@gna.ch>1992-05-15 03:21:10 +0000
commite556b972d1ad64453b3372b486191e2a59c91dda (patch)
tree4eb9264758c36cc75cdcf8daf8dde1517d77cb6a /Source/GetColorTab.S
parent36c824864c02f0a3f62c8a1d365d1670835c8c96 (diff)
downloadiff-library-e556b972d1ad64453b3372b486191e2a59c91dda.tar.gz
iff-library-e556b972d1ad64453b3372b486191e2a59c91dda.tar.bz2
iff-library-e556b972d1ad64453b3372b486191e2a59c91dda.zip
An neue Include-Files angepasst
Diffstat (limited to 'Source/GetColorTab.S')
-rw-r--r--Source/GetColorTab.S26
1 files changed, 14 insertions, 12 deletions
diff --git a/Source/GetColorTab.S b/Source/GetColorTab.S
index e7adcb6..7512653 100644
--- a/Source/GetColorTab.S
+++ b/Source/GetColorTab.S
@@ -1,13 +1,13 @@
**
-** $Id: $
-** $Revision: $
+** $Id: GetColorTab.S,v 1.1 92/05/12 22:26:12 chris Exp $
+** $Revision: 1.1 $
**
** $Filename: GetColorTab.S $
-** $Author: Christian A. Weber $
+** $Author: chris $
** $Release: 19.1 $
-** $Date: 92/05/11 21:11:27 $
+** $Date: 92/05/12 22:26:12 $
**
-** iff.library/IFFLib_GetColorTab
+** iff.library/IFFL_GetColorTab
**
** COPYRIGHT (C) 1987-1992 BY CHRISTIAN A. WEBER, BRUGGERWEG 2,
** CH-8037 ZUERICH, SWITZERLAND. ALL RIGHTS RESERVED. NO PART
@@ -17,7 +17,7 @@
**
- IDNT IFFLib_GetColorTab
+ IDNT IFFL_GetColorTab
SECTION text,CODE
INCLUDE "IFFLib.i"
@@ -26,14 +26,16 @@
XDEF GetColorTabFunc
-******* iff.library/IFFLib_GetColorTab **************************************
+******* iff.library/IFFL_GetColorTab ****************************************
*
* NAME
* IFFLib_GetColorTab -- find a CMAP and convert it to a ColorTable
*
* SYNOPSIS
-* count = IFFLib_GetColorTab( ifffile, colortable )
-* D0 A1 A0
+* count = IFFL_GetColorTab( iff, colortable )
+* D0 A1 A0
+*
+* LONG IFFFL_GetColorTab( IFF_HANDLE, UWORD * )
*
* FUNCTION
* Searches the CMAP chunk of an IFF file and converts it, if it's
@@ -41,7 +43,7 @@
* directly be used as a parameter for the LoadRGB4() function.
*
* INPUTS
-* ifffile - IFF file pointer, returned by IFFLib_OpenIFF()
+* iff - IFF file handle, from IFFL_OpenIFF()
* colortable - Pointer to a block of memory which must be large
* enough to hold the colortable (2 bytes per color).
* Must be WORD aligned.
@@ -51,7 +53,7 @@
* CMAP chunk
*
* SEE ALSO
-* IFFLib_FindChunk(), IFFLib_GetBMHD()
+* IFFL_FindChunk(), IFFL_GetBMHD()
*
*****************************************************************************
@@ -26,14 +26,16 @@
*
* NAME
-* IFFLib_GetColorTab -- find a CMAP and convert it to a ColorTable
+* IFFL_GetColorTab -- find a CMAP and convert it to a ColorTable
*
* SYNOPSIS